@@ -59,7 +59,10 @@ INVALIDPARAMETERVALUE_INSTANCENAMETOOLONG = 'InvalidParameterValue.InstanceNameT
 # 应用ID格式非法
 INVALIDPARAMETERVALUE_INVALIDAPPLICATIONIDMALFORMED = 'InvalidParameterValue.InvalidApplicationIdMalformed'
 
-# 应用类型application-type仅可以选择PUBLIC_APPLICATION或PRIVATE_APPLICATION。
+# 自定义应用名称重复
+INVALIDPARAMETERVALUE_INVALIDAPPLICATIONNAMEDUPLICATE = 'InvalidParameterValue.InvalidApplicationNameDuplicate'
+
+# 应用类型application-type仅可以选择PUBLIC_APPLICATION,PRIVATE_APPLICATION或COMMUNITY_APPLICATION
 INVALIDPARAMETERVALUE_INVALIDAPPLICATIONTYPE = 'InvalidParameterValue.InvalidApplicationType'
 
 # 付费方式字段不符合规范
@@ -122,6 +125,9 @@ UNAUTHORIZEDOPERATION_UNAUTHORIZEDUSER = 'UnauthorizedOperation.UnauthorizedUser
 # 不允许同时操作预付费过期实例和未过期实例
 UNSUPPORTEDOPERATION_CANNOTTERMINATEEXPIREDANDNOTEXPIREDINSTANCES = 'UnsupportedOperation.CannotTerminateExpiredAndNotExpiredInstances'
 
+# 实例不支持创建自定义应用
+UNSUPPORTEDOPERATION_INSTANCECREATEAPPLICATIONNOTSUPPORT = 'UnsupportedOperation.InstanceCreateApplicationNotSupport'
+
 # 不支持对处于`Arrears`状态的实例执行当前操作。
 UNSUPPORTEDOPERATION_INSTANCESTATEARREARS = 'UnsupportedOperation.InstanceStateArrears'
 
